Rev 16: Rename collapse_by_author -> collapse_by_person since author has an unambigous meaning in file:///data/jelmer/bzr-stats/trunk/

Jelmer Vernooij jelmer at samba.org
Sat Jun 28 20:06:38 BST 2008


At file:///data/jelmer/bzr-stats/trunk/

------------------------------------------------------------
revno: 16
revision-id: jelmer at samba.org-20080628190638-ogqyfqb715ys0yum
parent: jelmer at samba.org-20080628185437-xzv17ocr98h93h19
committer: Jelmer Vernooij <jelmer at samba.org>
branch nick: trunk
timestamp: Sat 2008-06-28 21:06:38 +0200
message:
  Rename collapse_by_author -> collapse_by_person since author has an unambigous meaning
modified:
  __init__.py                    __init__.py-20060629132721-mkbaty0vfk4y3v59-1
=== modified file '__init__.py'
--- a/__init__.py	2008-03-09 15:51:12 +0000
+++ b/__init__.py	2008-06-28 19:06:38 +0000
@@ -45,8 +45,8 @@
     return sorted(((count, name) for name,count in counts.iteritems()), reverse=True)
 
 
-def collapse_by_author(committers):
-    """The committers list is sorted by email, fix it up by author.
+def collapse_by_person(committers):
+    """The committers list is sorted by email, fix it up by person.
 
     Some people commit with a similar username, but different email
     address. Which makes it hard to sort out when they have multiple
@@ -125,7 +125,7 @@
         a_repo.unlock()
         pb.finished()
 
-    return collapse_by_author(committers)
+    return collapse_by_person(committers)
 
 
 def get_diff_info(a_repo, start_rev, end_rev):
@@ -156,9 +156,10 @@
         a_repo.unlock()
         pb.finished()
 
-    info = collapse_by_author(committers)
+    info = collapse_by_person(committers)
     return info
 
+
 def display_info(info, to_file):
     """Write out the information"""
 




More information about the bazaar-commits mailing list